@@ -1,8 +1,8 @@
 #' @importFrom abind abind
-#' @importFrom dplyr %>%  arrange filter group_by left_join mutate pull select summarize
+#' @importFrom dplyr %>%  all_of arrange bind_rows filter group_by left_join mutate pull select summarize
 #' summarise
-#' @importFrom ggplot2 aes element_blank expand_limits facet_wrap geom_boxplot
-#' ggplot ggplotGrob geom_rect geom_point labs theme theme_classic xlim ylim xlab ylab
+#' @importFrom ggplot2 aes element_blank expand_limits facet_wrap geom_boxplot geom_line
+#' ggplot ggplotGrob geom_rect geom_point labs theme theme_bw theme_classic xlim ylim xlab ylab
 #' @importFrom graphics abline arrows axis axTicks barplot boxplot contour hist
 #' identify layout legend
 #'  lines matplot mtext par plot plot.new points polygon segments text title text
@@ -49,7 +49,9 @@ Names <- c("maxage", "R0", "Mexp", "Msd", "dep", "D", "Mgrad", "SRrel", "hs", "p
            'Era', 'SpawnBio', 'Yr', "Sex", 'Beg/Mid', 'steep','int_Age', 'Len_Beg',
            'Wt_Beg', 'Len_Mat', 'Age_Mat', 'Age', "Yr", 'LAA', 'Gender', 'Year',
            'true_Age', 'true_Year', 'true_Yr', 'exp_recr', 'pred_recr', 'Z',
-           'season_as_years', 'nseas', 'SR', 'ReqData'
+           'season_as_years', 'nseas', 'SR', 'ReqData',
+           'Bio_all', 'B', 'C', 'Catch', 'Exp', 'Fleet', 'Model', 'N', 'R', 'SB',
+           'SB0', 'Sim', 'age', 'name', 'seas', 'value'
 )
 
 if(getRversion() >= "2.15.1") utils::globalVariables(Names)
